local mod = ...



-- Building: Thatcher -------------------------------------------------------------------------------------
mod:registerAsset({
	DataType = "BUILDING", 
	Id = "BUILDING_BASIC_THATCHER",
	Name = "BUILDING_BASIC_THATCHER_NAME",
	Description = "BUILDING_BASIC_THATCHER_DESC",
	BuildingType = "RESOURCE_PRODUCTION",
	AssetCoreBuildingPart = "BUILDING_PART_MONUMENT_POLE",
	VillagerRequired = { Status = "NEWCOMER", Quantity = 10 },
	IsEditable = true,
	BuildingPartSetList = {
		{
			Name = "BUILDING_SET_BASIC_THATCHER1_NAME",
			BuildingPartList = { 
				"BUILDING_PART_BASIC_THATCHER",
				"BUILDING_PART_BASIC_REEDBED",
			}
		},
    }
})



-- Building Part: Thatcher -------------------------------------------------------------------------------------
mod:registerAsset({
	DataType = "BUILDING_PART",
	Id = "BUILDING_PART_BASIC_THATCHER",
	Name = "BUILDING_PART_BASIC_THATCHER_NAME", 
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_BASIC_THATCHER",
        MiniatureConfig = {
            ClipUnderGround = true,
            GroupHeight = 0.0,
            CameraPosition = { 0, 0.6, -15 },
            OrientationOffset = 0.0,
            CameraPitchOffset = 20.0
        },
	},
	BuildingZone = { 
		ZoneEntryList = {
			{ 
				Polygon = polygon.createCircle( 3, {0, 0}, 10 ),
				Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = false } 
			},
		}
	},
	AssetBuildingFunction = "BUILDING_FUNCTION_BASIC_THATCHER",
	Cost = {
        ResourceNeededList = {
            {
                { Resource = "TOOL", Quantity = 2 },
            },
        }
	}
})



-- Building Part: Reed bed -------------------------------------------------------------------------------------
mod:registerAsset({
	DataType = "BUILDING_PART",
	Id = "BUILDING_PART_BASIC_REEDBED",
	Name = "BUILDING_PART_BASIC_REEDBED_NAME", 
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_BASIC_REEDBED"
    }
})



-- Job: Thatcher -------------------------------------------------------------------------------------
mod:registerAsset({
	DataType = "JOB",
	Id = "JOB_BASIC_THATCHER",
	JobName = "JOB_BASIC_THATCHER_NAME",
	JobDescription = "JOB_BASIC_THATCHER_DESC",
	IsLockedByDefault = false,
	DefaultBehavior = "BEHAVIOR_GATHER",
	UseWorkplaceBehavior = true,
    ProductionDelay = 2.5, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP", 
        RightHandObject = {
			Model = "PREFAB_TOOL_FARMER_SICKLE",
			-- KeepObjectOnWalkCycle = true,
            WorkAttachName = "Sickle_Anchor"
			-- WalkAttachName = "Sickle_Anchor"
        },
		-- WalkAnimation = "SCYTHE_WALK",
		IdleAnimation = "SCYTHE"
	}
})

mod:overrideAsset({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_BASIC_THATCHER"
    }
})

mod:overrideAsset({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_BASIC_THATCHER"
    }
})



-- -- Resource: Thatch -------------------------------------------------------------------------------------
-- mod:registerAssetId("icons/Thatch.png", "ICON_THATCH")

-- mod:registerAsset({
-- 	DataType = "RESOURCE",
-- 	Id = "RESOURCE_THATCH",
-- 	ResourceName = "RESOURCE_THATCH_NAME",
-- 	Icon = "ICON_THATCH",
-- 	ResourceTypeList = { "RESOURCE" },
-- 	IsTradable = true,
--     DisplayInInventory = true,
-- 	DisplayInToolbar = false,
-- 	OrderId = 0
-- })



-- Building Function: Thatcher -------------------------------------------------------------------------------------
mod:registerAsset({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
    Id = "BUILDING_FUNCTION_BASIC_THATCHER",
    Name = "BUILDING_FUNCTION_BASIC_THATCHER_NAME",
    WorkerCapacity = 2,
    RelatedJob = { 
        Job = "JOB_BASIC_THATCHER", 
        Behavior = "BEHAVIOR_GATHER"
    },
    InputInventoryCapacity = {
		{ Resource = "RESOURCE_THATCH", Quantity = 1 }, 
	},
    ResourceListNeeded = {
		{ Resource = "RESOURCE_THATCH", Quantity = 1 }, 
	},
	ResourceProduced = {
        { Resource = "RESOURCE_THATCH", Quantity = 1 },
    }
})